"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LambdaHelper = void 0;
const Lambda = require("@aws-sdk/client-lambda");
const typescript_helper_functions_1 = require("typescript-helper-functions");
const stream_1 = require("stream");
class LambdaHelper extends typescript_helper_functions_1.BaseClass {
    Repository;
    DefaultDynamoBatchSize = 100;
    DefaultKinesisBatchSize = 100;
    DefaultSQSBatchSize = 10;
    constructor(logger, repository, options) {
        super(logger);
        options = this.ObjectOperations.IsNullOrEmpty(options)
            ? { region: 'us-east-1' }
            :
                options;
        this.Repository = repository || new Lambda.Lambda(options);
    }
    async DisableDynamoEventSourceMappingAsync(functionName, uuid, batchSize) {
        return await this.UpdateEventSourceMappingAsync(functionName, false, uuid, batchSize || this.DefaultDynamoBatchSize);
    }
    async DisableKinesisEventSourceMappingAsync(functionName, uuid, batchSize) {
        return await this.UpdateEventSourceMappingAsync(functionName, false, uuid, batchSize || this.DefaultKinesisBatchSize);
    }
    async DisableSQSEventSourceMappingAsync(functionName, uuid, batchSize) {
        return await this.UpdateEventSourceMappingAsync(functionName, false, uuid, batchSize || this.DefaultSQSBatchSize);
    }
    async EnableDynamoEventSourceMappingAsync(functionName, uuid, batchSize) {
        return await this.UpdateEventSourceMappingAsync(functionName, true, uuid, batchSize || this.DefaultDynamoBatchSize);
    }
    async EnableKinesisEventSourceMappingAsync(functionName, uuid, batchSize) {
        return await this.UpdateEventSourceMappingAsync(functionName, true, uuid, batchSize || this.DefaultKinesisBatchSize);
    }
    async EnableSQSEventSourceMappingAsync(functionName, uuid, batchSize) {
        return await this.UpdateEventSourceMappingAsync(functionName, true, uuid, batchSize || this.DefaultSQSBatchSize);
    }
    async GetEventSourceMappingAsync(uuid) {
        const action = `${LambdaHelper.name}.${this.GetEventSourceMappingAsync.name}`;
        this.LogHelper.LogInputs(action, { uuid });
        if (this.ObjectOperations.IsNullOrWhitespace(uuid)) {
            throw new Error(`[${action}]-Must supply uuid`);
        }
        const params = {
            UUID: uuid,
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.getEventSourceMapping(params);
        this.LogHelper.LogResponse(action, response);
        return response;
    }
    async ListEventSourceMappingsAsync(functionName, eventSourceArn) {
        const action = `${LambdaHelper.name}.${this.ListEventSourceMappingsAsync.name}`;
        this.LogHelper.LogInputs(action, { functionName, eventSourceArn });
        if (this.ObjectOperations.IsNullOrWhitespace(functionName)) {
            throw new Error(`[${action}]-Must supply functionName`);
        }
        if (this.ObjectOperations.IsNullOrWhitespace(eventSourceArn)) {
            throw new Error(`[${action}]-Must supply eventSourceArn`);
        }
        const params = {
            EventSourceArn: eventSourceArn,
            FunctionName: functionName,
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.listEventSourceMappings(params);
        this.LogHelper.LogResponse(action, response);
        return response;
    }
    async InvokeAsync(functionName, payload) {
        const action = `${LambdaHelper.name}.${this.InvokeAsync.name}`;
        this.LogHelper.LogInputs(action, { functionName, payload });
        if (this.ObjectOperations.IsNullOrWhitespace(functionName)) {
            throw new Error(`[${action}]-Must supply functionName`);
        }
        const payloadString = JSON.stringify(payload);
        const readable = new stream_1.Readable();
        readable.push(payloadString);
        readable.push(null);
        const params = {
            FunctionName: functionName,
            InvokeArgs: readable,
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.invokeAsync(params);
        this.LogHelper.LogResponse(action, response);
        return response;
    }
    async InvokeSync(functionName, payload) {
        const action = `${LambdaHelper.name}.${this.InvokeSync.name}`;
        this.LogHelper.LogInputs(action, { functionName, payload });
        if (this.ObjectOperations.IsNullOrWhitespace(functionName)) {
            throw new Error(`[${action}]-Must supply functionName`);
        }
        const payloadString = JSON.stringify(payload);
        const array = this.ObjectOperations.ConvertStringToArrayBuffer(payloadString);
        const params = {
            FunctionName: functionName,
            Payload: array,
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.invoke(params);
        this.LogHelper.LogResponse(action, response);
        return response;
    }
    async UpdateEventSourceMappingAsync(functionName, enabled, uuid, batchSize) {
        const action = `${LambdaHelper.name}.${this.UpdateEventSourceMappingAsync.name}`;
        this.LogHelper.LogInputs(action, {
            functionName,
            enabled,
            uuid,
            batchSize,
        });
        if (this.ObjectOperations.IsNullOrWhitespace(functionName)) {
            throw new Error(`[${action}]-Must supply functionName`);
        }
        if (this.ObjectOperations.IsNullOrWhitespace(uuid)) {
            throw new Error(`[${action}]-Must supply uuid`);
        }
        const params = {
            BatchSize: batchSize,
            Enabled: enabled,
            FunctionName: functionName,
            UUID: uuid,
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.updateEventSourceMapping(params);
        this.LogHelper.LogResponse(action, response);
        return response;
    }
}
exports.LambdaHelper = LambdaHelper;
//# sourceMappingURL=helper.js.map